import { MediaPackageClient } from "./MediaPackageClient";
import { CreateChannelInput } from "./types/CreateChannelInput";
import { CreateChannelOutput } from "./types/CreateChannelOutput";
import { CreateOriginEndpointInput } from "./types/CreateOriginEndpointInput";
import { CreateOriginEndpointOutput } from "./types/CreateOriginEndpointOutput";
import { DeleteChannelInput } from "./types/DeleteChannelInput";
import { DeleteChannelOutput } from "./types/DeleteChannelOutput";
import { DeleteOriginEndpointInput } from "./types/DeleteOriginEndpointInput";
import { DeleteOriginEndpointOutput } from "./types/DeleteOriginEndpointOutput";
import { DescribeChannelInput } from "./types/DescribeChannelInput";
import { DescribeChannelOutput } from "./types/DescribeChannelOutput";
import { DescribeOriginEndpointInput } from "./types/DescribeOriginEndpointInput";
import { DescribeOriginEndpointOutput } from "./types/DescribeOriginEndpointOutput";
import { ListChannelsInput } from "./types/ListChannelsInput";
import { ListChannelsOutput } from "./types/ListChannelsOutput";
import { ListOriginEndpointsInput } from "./types/ListOriginEndpointsInput";
import { ListOriginEndpointsOutput } from "./types/ListOriginEndpointsOutput";
import { ListTagsForResourceInput } from "./types/ListTagsForResourceInput";
import { ListTagsForResourceOutput } from "./types/ListTagsForResourceOutput";
import { RotateChannelCredentialsInput } from "./types/RotateChannelCredentialsInput";
import { RotateChannelCredentialsOutput } from "./types/RotateChannelCredentialsOutput";
import { RotateIngestEndpointCredentialsInput } from "./types/RotateIngestEndpointCredentialsInput";
import { RotateIngestEndpointCredentialsOutput } from "./types/RotateIngestEndpointCredentialsOutput";
import { TagResourceInput } from "./types/TagResourceInput";
import { TagResourceOutput } from "./types/TagResourceOutput";
import { UntagResourceInput } from "./types/UntagResourceInput";
import { UntagResourceOutput } from "./types/UntagResourceOutput";
import { UpdateChannelInput } from "./types/UpdateChannelInput";
import { UpdateChannelOutput } from "./types/UpdateChannelOutput";
import { UpdateOriginEndpointInput } from "./types/UpdateOriginEndpointInput";
import { UpdateOriginEndpointOutput } from "./types/UpdateOriginEndpointOutput";
export declare class MediaPackage extends MediaPackageClient {
    /**
     * Creates a new Channel.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createChannel(args: CreateChannelInput): Promise<CreateChannelOutput>;
    createChannel(args: CreateChannelInput, cb: (err: any, data?: CreateChannelOutput) => void): void;
    /**
     * Creates a new OriginEndpoint record.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    createOriginEndpoint(args: CreateOriginEndpointInput): Promise<CreateOriginEndpointOutput>;
    createOriginEndpoint(args: CreateOriginEndpointInput, cb: (err: any, data?: CreateOriginEndpointOutput) => void): void;
    /**
     * Deletes an existing Channel.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteChannel(args: DeleteChannelInput): Promise<DeleteChannelOutput>;
    deleteChannel(args: DeleteChannelInput, cb: (err: any, data?: DeleteChannelOutput) => void): void;
    /**
     * Deletes an existing OriginEndpoint.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    deleteOriginEndpoint(args: DeleteOriginEndpointInput): Promise<DeleteOriginEndpointOutput>;
    deleteOriginEndpoint(args: DeleteOriginEndpointInput, cb: (err: any, data?: DeleteOriginEndpointOutput) => void): void;
    /**
     * Gets details about a Channel.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeChannel(args: DescribeChannelInput): Promise<DescribeChannelOutput>;
    describeChannel(args: DescribeChannelInput, cb: (err: any, data?: DescribeChannelOutput) => void): void;
    /**
     * Gets details about an existing OriginEndpoint.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    describeOriginEndpoint(args: DescribeOriginEndpointInput): Promise<DescribeOriginEndpointOutput>;
    describeOriginEndpoint(args: DescribeOriginEndpointInput, cb: (err: any, data?: DescribeOriginEndpointOutput) => void): void;
    /**
     * Returns a collection of Channels.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listChannels(args: ListChannelsInput): Promise<ListChannelsOutput>;
    listChannels(args: ListChannelsInput, cb: (err: any, data?: ListChannelsOutput) => void): void;
    /**
     * Returns a collection of OriginEndpoint records.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listOriginEndpoints(args: ListOriginEndpointsInput): Promise<ListOriginEndpointsOutput>;
    listOriginEndpoints(args: ListOriginEndpointsInput, cb: (err: any, data?: ListOriginEndpointsOutput) => void): void;
    /**
     * ListTagsForResource operation
     *
     * This operation may fail with one of the following errors:
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    listTagsForResource(args: ListTagsForResourceInput): Promise<ListTagsForResourceOutput>;
    listTagsForResource(args: ListTagsForResourceInput, cb: (err: any, data?: ListTagsForResourceOutput) => void): void;
    /**
     * Changes the Channel's first IngestEndpoint's username and password. WARNING - This API is deprecated. Please use RotateIngestEndpointCredentials instead
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    rotateChannelCredentials(args: RotateChannelCredentialsInput): Promise<RotateChannelCredentialsOutput>;
    rotateChannelCredentials(args: RotateChannelCredentialsInput, cb: (err: any, data?: RotateChannelCredentialsOutput) => void): void;
    /**
     * Rotate the IngestEndpoint's username and password, as specified by the IngestEndpoint's id.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    rotateIngestEndpointCredentials(args: RotateIngestEndpointCredentialsInput): Promise<RotateIngestEndpointCredentialsOutput>;
    rotateIngestEndpointCredentials(args: RotateIngestEndpointCredentialsInput, cb: (err: any, data?: RotateIngestEndpointCredentialsOutput) => void): void;
    /**
     * TagResource operation
     *
     * This operation may fail with one of the following errors:
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    tagResource(args: TagResourceInput): Promise<TagResourceOutput>;
    tagResource(args: TagResourceInput, cb: (err: any, data?: TagResourceOutput) => void): void;
    /**
     * UntagResource operation
     *
     * This operation may fail with one of the following errors:
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    untagResource(args: UntagResourceInput): Promise<UntagResourceOutput>;
    untagResource(args: UntagResourceInput, cb: (err: any, data?: UntagResourceOutput) => void): void;
    /**
     * Updates an existing Channel.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateChannel(args: UpdateChannelInput): Promise<UpdateChannelOutput>;
    updateChannel(args: UpdateChannelInput, cb: (err: any, data?: UpdateChannelOutput) => void): void;
    /**
     * Updates an existing OriginEndpoint.
     *
     * This operation may fail with one of the following errors:
     *   - {UnprocessableEntityException} The parameters sent in the request are not valid.
     *   - {InternalServerErrorException} An unexpected error occurred.
     *   - {ForbiddenException} The client is not authorized to access the requested resource.
     *   - {NotFoundException} The requested resource does not exist.
     *   - {ServiceUnavailableException} An unexpected error occurred.
     *   - {TooManyRequestsException} The client has exceeded their resource or throttling limits.
     *   - {Error} An error originating from the SDK or customizations rather than the service
     */
    updateOriginEndpoint(args: UpdateOriginEndpointInput): Promise<UpdateOriginEndpointOutput>;
    updateOriginEndpoint(args: UpdateOriginEndpointInput, cb: (err: any, data?: UpdateOriginEndpointOutput) => void): void;
}
